@@ -209,7 +209,7 @@ PAlist = {
         "Wukong": "Ninkondi,Zhuge",
         "Zephyr": "Kronen,Tiberon",
         "Harrow": "Knell,Scourge",
-        "Garuda": "Corvas,Nangantaka",
+        "Garuda": "Corvas,Nagantaka",
         "Khora": "Hystrix,Dual Keres",
         "Revenant": "Phantasma,Tatsu",
         "Baruuk": "Afuris,Cobra & Crane"
